@@ -17,7 +17,7 @@ bayestestR::equivalence_test
 #'   equivalence. Can be `"bayes"`, `"classic"` or `"cet"`. See
 #'   'Details'.
 #' @param test Hypothesis test for computing contrasts or pairwise comparisons.
-#'   See [`?ggeffects::hypothesis_test`](https://strengejacke.github.io/ggeffects/reference/hypothesis_test.html)
+#'   See [`?ggeffects::test_predictions`](https://strengejacke.github.io/ggeffects/reference/test_predictions.html)
 #'   for details.
 #' @param verbose Toggle warnings and messages.
 #' @param ... Arguments passed to or from other methods.
@@ -31,11 +31,11 @@ bayestestR::equivalence_test
 #' In classical null hypothesis significance testing (NHST) within a frequentist
 #' framework, it is not possible to accept the null hypothesis, H0 - unlike
 #' in Bayesian statistics, where such probability statements are possible.
-#' \dQuote{[...] one can only reject the null hypothesis if the test
+#' "[...] one can only reject the null hypothesis if the test
 #' statistics falls into the critical region(s), or fail to reject this
 #' hypothesis. In the latter case, all we can say is that no significant effect
-#' was observed, but one cannot conclude that the null hypothesis is true.}
-#' (\cite{Pernet 2017}). One way to address this issues without Bayesian methods
+#' was observed, but one cannot conclude that the null hypothesis is true."
+#' (_Pernet 2017_). One way to address this issues without Bayesian methods
 #' is *Equivalence Testing*, as implemented in `equivalence_test()`.
 #' While you either can reject the null hypothesis or claim an inconclusive result
 #' in NHST, the equivalence test - according to _Pernet_ - adds a third category,
@@ -50,9 +50,8 @@ bayestestR::equivalence_test
 #' ## Calculation of equivalence testing
 #' - "bayes" - Bayesian rule (Kruschke 2018)
 #'
-#'   This rule follows the \dQuote{HDI+ROPE decision rule} \cite{(Kruschke,
-#'   2014, 2018)} used for the
-#'   [`Bayesian counterpart()`][bayestestR::equivalence_test]. This
+#'   This rule follows the "HDI+ROPE decision rule" (_Kruschke, 2014, 2018_) used
+#'   for the [`Bayesian counterpart()`][bayestestR::equivalence_test]. This
 #'   means, if the confidence intervals are completely outside the ROPE, the
 #'   "null hypothesis" for this parameter is "rejected". If the ROPE
 #'   completely covers the CI, the null hypothesis is accepted. Else, it's
@@ -315,11 +314,11 @@ equivalence_test.ggeffects <- function(x,
 
   x <- .get_ggeffects_model(x)
 
-  # sanity check rope range
+  # validation check rope range
   rule <- match.arg(tolower(rule), choices = c("bayes", "classic", "cet"))
   range <- .check_rope_range(x, range, verbose)
 
-  out <- ggeffects::hypothesis_test(
+  out <- ggeffects::test_predictions(
     x,
     terms = focal,
     test = test,
