@@ -46,6 +46,9 @@ print_html.parameters_model <- function(x,
   if (missing(select) || is.null(select)) {
     select <- attributes(x)$output_style
   }
+  if (missing(groups)) {
+    groups <- attributes(x)$parameter_groups
+  }
 
   # we need glue-like syntax right now...
   if (!is.null(select)) {
@@ -150,6 +153,7 @@ print_html.compare_parameters <- function(x,
                                           font_size = "100%",
                                           line_padding = 4,
                                           column_labels = NULL,
+                                          engine = "gt",
                                           ...) {
   # check if user supplied digits attributes
   if (missing(digits)) {
@@ -169,6 +173,29 @@ print_html.compare_parameters <- function(x,
     select <- attributes(x)$output_style
   }
 
+  # markdown engine?
+  engine <- match.arg(getOption("easystats_html_engine", engine), c("gt", "default", "tt"))
+
+  # for tiny table, we can just call print_md()
+  if (engine == "tt") {
+    return(print_md(
+      x,
+      digits = digits,
+      ci_digits = ci_digits,
+      p_digits = p_digits,
+      caption = caption,
+      subtitle = subtitle,
+      footer = footer,
+      select = select,
+      split_components = TRUE,
+      ci_brackets = ci_brackets,
+      zap_small = zap_small,
+      groups = groups,
+      engine = "tt",
+      outformat = "html"
+    ))
+  }
+
   # we need glue-like syntax right now...
   select <- .convert_to_glue_syntax(style = select, "<br>")
 
@@ -233,7 +260,7 @@ print_html.compare_parameters <- function(x,
   if (!is.null(user_labels)) {
     new_labels <- c(
       colnames(out[["_data"]])[1],
-      rep(user_labels, length.out = ncol(out[["_data"]]) - 1)
+      rep_len(user_labels, ncol(out[["_data"]]) - 1)
     )
     new_labels <- as.list(new_labels)
   }
@@ -270,7 +297,7 @@ print_html.compare_parameters <- function(x,
   # check where last parameter row ends. For "compare_models()", the
   # first Parameter value after data rows is "". If this is not found,
   # simply use number of rows as last row
-  last_row <- which(out[["_data"]][[pcol_name]] == "")[1]
+  last_row <- which(!nzchar(as.character(out[["_data"]][[pcol_name]]), keepNA = TRUE))[1]
   if (is.na(last_row)) {
     last_row <- nrow(out[["_data"]])
   } else {
