@@ -91,10 +91,10 @@ print_md.parameters_model <- function(x,
     footer <- ""
   }
   if (!identical(footer, "")) {
-    if (!is.null(footer)) {
-      footer <- paste0("\n", footer, "\n", footer_stats)
-    } else {
+    if (is.null(footer)) {
       footer <- footer_stats
+    } else {
+      footer <- paste0("\n", footer, "\n", footer_stats)
     }
   }
 
@@ -133,6 +133,10 @@ print_md.compare_parameters <- function(x,
                                         footer = NULL,
                                         select = NULL,
                                         split_components = TRUE,
+                                        ci_brackets = c("(", ")"),
+                                        zap_small = FALSE,
+                                        groups = NULL,
+                                        engine = "tt",
                                         ...) {
   # check if user supplied digits attributes
   if (missing(digits)) {
@@ -149,6 +153,12 @@ print_md.compare_parameters <- function(x,
   if (missing(select) || is.null(select)) {
     select <- attributes(x)$output_style
   }
+  if (missing(groups)) {
+    groups <- attributes(x)$parameter_groups
+  }
+
+  # markdown engine?
+  engine <- match.arg(engine, c("tt", "default"))
 
   formatted_table <- format(
     x,
@@ -158,17 +168,38 @@ print_md.compare_parameters <- function(x,
     ci_digits = ci_digits,
     p_digits = p_digits,
     ci_width = NULL,
-    ci_brackets = c("(", ")"),
-    format = "markdown"
+    ci_brackets = ci_brackets,
+    format = "markdown",
+    zap_small = zap_small,
+    groups = groups,
+    engine = engine
   )
 
-  insight::export_table(
-    formatted_table,
-    format = "markdown",
-    caption = caption,
-    subtitle = subtitle,
-    footer = footer
-  )
+  if (identical(engine, "tt")) {
+    # retrieve output format - print_md() may be called from print_html()
+    dots <- list(...)
+    if (identical(dots$outformat, "html")) {
+      outformat <- "html"
+    } else {
+      outformat <- "markdown"
+    }
+    .export_table_tt(
+      x,
+      formatted_table,
+      groups,
+      caption = caption,
+      footer = footer,
+      outformat = outformat
+    )
+  } else {
+    insight::export_table(
+      formatted_table,
+      format = "markdown",
+      caption = caption,
+      subtitle = subtitle,
+      footer = footer
+    )
+  }
 }
 
 
@@ -257,14 +288,12 @@ print_md.equivalence_test_lm <- function(x, digits = 2, ci_brackets = c("(", ")"
   rule <- attributes(x)$rule
   rope <- attributes(x)$rope
 
-  if (!is.null(rule)) {
-    if (rule == "cet") {
-      table_caption <- "Conditional Equivalence Testing"
-    } else if (rule == "classic") {
-      table_caption <- "TOST-test for Practical Equivalence"
-    } else {
-      table_caption <- "Test for Practical Equivalence"
-    }
+  if (is.null(rule)) {
+    table_caption <- "Test for Practical Equivalence"
+  } else if (rule == "cet") {
+    table_caption <- "Conditional Equivalence Testing"
+  } else if (rule == "classic") {
+    table_caption <- "TOST-test for Practical Equivalence"
   } else {
     table_caption <- "Test for Practical Equivalence"
   }
@@ -324,11 +353,100 @@ print_md.parameters_distribution <- function(x, digits = 2, ci_brackets = c("(",
 }
 
 
+# helper -----------------------
 
-
-
-# Reexports models ------------------------
-
-#' @importFrom insight print_md
-#' @export
-insight::print_md
+.export_table_tt <- function(x, formatted_table, groups, caption = NULL, footer = NULL, outformat = "markdown") {
+  insight::check_if_installed("tinytable", minimum_version = "0.1.0")
+  row_groups <- NULL
+  # check if we have a list of tables
+  if (!is.data.frame(formatted_table) && is.list(formatted_table) && length(formatted_table) > 1) {
+    # sanity check - cannot combine multiple tables when we have groups
+    if (!is.null(groups)) {
+      insight::format_error("Cannot combine multiple tables when groups are present.")
+    }
+    # add table caption as group variable, and bind tables
+    # we then extract row headers based on values in the group indices
+    formatted_table <- lapply(formatted_table, function(i) {
+      i$group <- attr(i, "table_caption")
+      i
+    })
+    # bind tables
+    formatted_table <- do.call(rbind, formatted_table)
+    # find positions for sub headers
+    row_groups <- as.list(which(!duplicated(formatted_table$group)))
+    names(row_groups) <- formatted_table$group[unlist(row_groups)]
+    # remove no longer needed group variable
+    formatted_table$group <- NULL
+  }
+  # we need to find out which columns refer to which model, in order to
+  # add a column heading for each model
+  models <- attributes(x)$model_names
+  col_names <- gsub("(.*) \\((.*)\\)$", "\\2", colnames(formatted_table))
+  col_groups <- sapply(models, function(i) which(i == col_names), simplify = FALSE)
+  # clean column names. These still contain the model name
+  colnames(formatted_table) <- gsub("(.*) \\((.*)\\)$", "\\1", colnames(formatted_table))
+  # check if we have column spans at all?
+  if (all(lengths(col_groups) == 1)) {
+    col_groups <- NULL
+  }
+  # group rows?
+  if (!is.null(groups)) {
+    # make sure we have numeric indices for groups
+    groups <- lapply(groups, function(g) {
+      if (is.character(g)) {
+        # if groups were provided as parameter names, we find the row position
+        # by matching the parameter name
+        match(g, formatted_table$Parameter)
+      } else {
+        # else, we assume that the group is a row position
+        g
+      }
+    })
+    # sanity check - do all rows match a parameter?
+    group_indices <- unlist(groups, use.names = FALSE)
+    if (anyNA(group_indices) || any(group_indices < 1) || any(group_indices > nrow(formatted_table))) {
+      insight::format_error("Some group indices do not match any parameter.")
+    }
+    # if row indices are not sorted, we need to resort the parameters data frame
+    if (is.unsorted(unlist(groups))) {
+      new_rows <- c(unlist(groups), setdiff(seq_len(nrow(formatted_table)), unlist(groups)))
+      formatted_table <- formatted_table[new_rows, ]
+      # we need to update indices in groups as well. Therefore, we need to convert
+      # list of row indices into a vector with row indices, then subtract the
+      # differences of old and new row positions, and then split that vector into
+      # a list again
+      groups <- stats::setNames(unlist(groups), rep(names(groups), lengths(groups)))
+      groups <- groups - (unlist(groups) - sort(unlist(groups)))
+      groups <- split(unname(groups), factor(names(groups), levels = unique(names(groups))))
+    }
+    # find matching rows for groups
+    row_groups <- lapply(seq_along(groups), function(i) {
+      g <- groups[[i]]
+      if (is.character(g)) {
+        # if groups were provided as parameter names, we find the row position
+        # by matching the parameter name
+        g <- match(g, formatted_table$Parameter)[1]
+      } else {
+        # else, we assume that the group is a row position
+        g <- g[1]
+      }
+      g
+    })
+    # set element names
+    names(row_groups) <- names(groups)
+    if (identical(outformat, "markdown")) {
+      # for markdown, format italic
+      names(row_groups) <- paste0("*", names(row_groups), "*")
+    }
+  }
+  # replace NA in formatted_table by ""
+  formatted_table[is.na(formatted_table)] <- ""
+  # create base table
+  out <- tinytable::tt(formatted_table, notes = footer, caption = caption)
+  # insert sub header rows and column spans, if we have them
+  if (!(is.null(row_groups) && is.null(col_groups))) {
+    out <- tinytable::group_tt(out, i = row_groups, j = col_groups)
+  }
+  out@output <- outformat
+  out
+}
