@@ -1,15 +1,16 @@
-skip_if_not_installed("marginaleffects", minimum_version = "0.15.0")
+skip_if_not_installed("marginaleffects", minimum_version = "0.18.0")
+skip_if_not_installed("insight", minimum_version = "0.19.9")
 skip_if_not_installed("rstanarm")
 
 test_that("marginaleffects()", {
   # Frequentist
   x <- lm(Sepal.Width ~ Species * Petal.Length, data = iris)
-  model <- marginaleffects::slopes(x, newdata = insight::get_datagrid(x, at = "Species"), variables = "Petal.Length")
+  model <- marginaleffects::avg_slopes(x, newdata = insight::get_datagrid(x, at = "Species"), variables = "Petal.Length")
   out <- parameters(model)
   expect_identical(nrow(out), 1L)
   expect_named(out, c(
-    "Parameter", "Comparison", "Coefficient", "SE", "Statistic",
-    "p", "CI", "CI_low", "CI_high"
+    "Parameter", "Coefficient", "SE", "Statistic",
+    "p", "S", "CI", "CI_low", "CI_high"
   ))
   out <- model_parameters(model, exponentiate = TRUE)
   expect_equal(out$Coefficient, 1.394, tolerance = 1e-3)
@@ -24,7 +25,7 @@ test_that("marginaleffects()", {
       chains = 1
     )
   )
-  model <- marginaleffects::slopes(x, newdata = insight::get_datagrid(x, at = "Species"), variables = "Petal.Length")
+  model <- marginaleffects::avg_slopes(x, newdata = insight::get_datagrid(x, at = "Species"), variables = "Petal.Length")
   expect_identical(nrow(parameters(model)), 1L)
 })
 
@@ -35,8 +36,8 @@ test_that("predictions()", {
   out <- parameters(p)
   expect_identical(nrow(out), 3L)
   expect_named(out, c(
-    "Predicted", "SE", "CI", "CI_low", "CI_high", "Statistic",
-    "p", "Species", "s.value"
+    "Predicted", "SE", "CI", "CI_low", "CI_high", "S", "Statistic",
+    "p", "Species"
   ))
   out <- parameters(p, exponentiate = TRUE)
   expect_equal(out$Predicted, c(30.81495, 15.95863, 19.57004), tolerance = 1e-4)
@@ -47,7 +48,7 @@ test_that("comparisons()", {
   data(iris)
   # Frequentist
   x <- lm(Sepal.Width ~ Species * Petal.Length, data = iris)
-  m <- marginaleffects::comparisons(x, newdata = insight::get_datagrid(x, at = "Species"), variables = "Petal.Length")
+  m <- marginaleffects::avg_comparisons(x, newdata = insight::get_datagrid(x, at = "Species"), variables = "Petal.Length")
   expect_identical(nrow(parameters(m)), 1L)
   out <- parameters(m, exponentiate = TRUE)
   expect_equal(out$Coefficient, 1.393999, tolerance = 1e-4)
@@ -62,7 +63,7 @@ test_that("comparisons()", {
       chains = 1
     )
   )
-  m <- marginaleffects::slopes(
+  m <- marginaleffects::avg_slopes(
     x,
     newdata = insight::get_datagrid(x, at = "Species"),
     variables = "Petal.Length"
@@ -71,17 +72,6 @@ test_that("comparisons()", {
 })
 
 
-test_that("marginalmeans()", {
-  data(mtcars)
-  dat <- mtcars
-  dat$cyl <- factor(dat$cyl)
-  dat$gear <- factor(dat$gear)
-  x <- lm(mpg ~ cyl + gear, data = dat)
-  m <- marginaleffects::marginalmeans(x)
-  expect_identical(nrow(parameters(m)), 6L)
-})
-
-
 test_that("hypotheses()", {
   data(mtcars)
   x <- lm(mpg ~ hp + wt, data = mtcars)
