@@ -8,20 +8,20 @@ withr::with_options(
   list(parameters_exponentiate = FALSE),
   {
     data(Transport, package = "mclogit")
-    invisible(capture.output(
+    invisible(capture.output({
       m1 <- mclogit::mclogit(
         cbind(resp, suburb) ~ distance + cost,
         data = Transport
       )
-    ))
+    }))
 
     data(housing, package = "MASS")
-    invisible(capture.output(
+    invisible(capture.output({
       m2 <- mclogit::mblogit(Sat ~ Infl + Type + Cont,
         weights = Freq,
         data = housing
       )
-    ))
+    }))
 
     test_that("model_parameters.mclogit", {
       params <- model_parameters(m1)
